Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateGroup ¶ added in v0.0.5
CreateGroup godoc @Summary Create a new group @Description Creates a new group and returns its ID @Tags Groups @Accept json @Produce json @Success 200 {object} GroupIDResponse @Failure 500 {object} errors.Error @Security BearerAuth @Router /admin/api/groups [post]
func CreateGroupPad ¶ added in v0.0.5
CreateGroupPad godoc @Summary Create a pad in a group @Description Creates a new pad within a group @Tags Groups @Accept json @Produce json @Param groupId path string true "Group ID" @Param request body CreateGroupPadRequest true "Pad data" @Success 200 {object} map[string]string @Failure 400 {object} errors.Error @Failure 404 {object} errors.Error @Failure 409 {object} errors.Error @Failure 500 {object} errors.Error @Security BearerAuth @Router /admin/api/groups/{groupId}/pads [post]
func DeleteGroup ¶ added in v0.0.5
DeleteGroup godoc @Summary Delete a group @Description Deletes a group @Tags Groups @Accept json @Produce json @Param groupId path string true "Group ID" @Success 200 {string} string "OK" @Failure 400 {object} errors.Error @Failure 404 {object} errors.Error @Failure 500 {object} errors.Error @Security BearerAuth @Router /admin/api/groups/{groupId} [delete]
Types ¶
type CreateGroupPadRequest ¶ added in v0.0.5
type CreateGroupPadRequest struct {
PadName string `json:"padName"`
Text string `json:"text"`
AuthorId string `json:"authorId"`
}
CreateGroupPadRequest represents the request to create a group pad
type GroupIDResponse ¶ added in v0.0.5
type GroupIDResponse struct {
GroupID string `json:"groupID"`
}
GroupIDResponse represents a response with a group ID