swagger

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Init

func Init(app *fiber.App)

Init registers the Swagger UI route The Swagger documentation is part of the binary through the import of github.com/ether/etherpad-go/docs The docs package is automatically embedded in the binary through the _ import

Types

This section is empty.

Jump to