plugins

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: Apache-2.0 Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

Functions

func GetCachedPackages added in v0.0.4

func GetCachedPackages() map[string]Plugin

GetCachedPackages returns cached packages, loading them if necessary

func GetCachedParts added in v0.0.4

func GetCachedParts() map[string]Part

GetCachedParts returns cached parts, loading them if necessary

func GetCachedPlugins added in v0.0.4

func GetCachedPlugins() map[string]Plugin

GetCachedPlugins returns cached plugins, loading them if necessary

func GetEnabledPackages added in v0.0.4

func GetEnabledPackages() map[string]Plugin

GetEnabledPackages gibt nur die in den Settings aktivierten Plugins zurück

func GetPackages

func GetPackages() map[string]Plugin

GetPackages gibt alle installierten Plugins zurück

func GetStoredPluginAssets added in v0.0.5

func GetStoredPluginAssets() embed.FS

GetStoredPluginAssets returns the stored plugin assets for use by other packages

func GetStoredUIAssets added in v0.0.5

func GetStoredUIAssets() embed.FS

GetStoredUIAssets returns the stored UI assets for use by other packages

func Init added in v0.0.5

func Init(uiAssets embed.FS, pluginAssets embed.FS)

func InitPlugins added in v0.0.4

func InitPlugins(store *interfaces.EpPluginStore)

func LoadPlugin

func LoadPlugin(plugin Plugin, plugins map[string]Plugin, parts map[string]Part)

func ReturnPluginResponse

func ReturnPluginResponse(c fiber.Ctx) error

func Update

func Update() (map[string]Plugin, map[string]Part, map[string]Plugin)

Types

type ClientPlugin

type ClientPlugin struct {
	Plugins map[string]string `json:"plugins"`
	Parts   []Part            `json:"parts"`
}

type Part

type Part struct {
	Name              string             `json:"name"`
	Hooks             map[string]string  `json:"hooks"`
	ClientHooks       map[string]string  `json:"client_hooks"`
	ToolbarButtons    []ToolbarButton    `json:"toolbar_buttons,omitempty"`
	SettingsMenuItems []SettingsMenuItem `json:"settings_menu_items,omitempty"`
	Plugin            *string            `json:"plugin"`
	FullName          *string            `json:"full_name"`
}

type Plugin

type Plugin struct {
	Name     string
	Version  string
	Path     string
	RealPath string
}

type PluginDef

type PluginDef struct {
	Parts []Part `json:"parts"`
}

type SettingsMenuItem added in v0.0.4

type SettingsMenuItem = pluginTypes.SettingsMenuItem

type SettingsMenuItemGroup added in v0.0.4

type SettingsMenuItemGroup = pluginTypes.SettingsMenuItemGroup

func GetSettingsMenuGroups added in v0.0.4

func GetSettingsMenuGroups() []SettingsMenuItemGroup

type ToolbarButton added in v0.0.4

type ToolbarButton = pluginTypes.ToolbarButton

ToolbarButton is an alias to the type in models/plugins

func GetToolbarButtons added in v0.0.4

func GetToolbarButtons() []ToolbarButton

GetToolbarButtons gibt alle Toolbar-Buttons von aktivierten Plugins zurück

type ToolbarButtonGroup added in v0.0.4

type ToolbarButtonGroup = pluginTypes.ToolbarButtonGroup

ToolbarButtonGroup is an alias to the type in models/plugins

func GetToolbarButtonGroups added in v0.0.4

func GetToolbarButtonGroups() []ToolbarButtonGroup

GetToolbarButtonGroups gibt Toolbar-Buttons gruppiert nach Plugin zurück

Jump to