package
Version:
v0.0.3
Opens a new window with list of versions in this module.
Published: Jan 13, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CreateDto struct {
Name string `json:"name" validate:"required"`
}
type CreateDtoResponse struct {
AuthorId string `json:"authorId"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.